==> jsbos-oauth-2025.12.dev-sources.jar: com/bringspring/oauth/granter/RkkjWxworkTokenGranter.java <==
package com.bringspring.oauth.granter;

import cn.dev33.satoken.context.SaHolder;
import com.bringspring.common.auth.consts.AuthConsts;
import com.bringspring.common.auth.consts.DeviceType;
import com.bringspring.common.auth.granter.AbstractTokenGranter;
import com.bringspring.common.auth.granter.UserDetailsServiceBuilder;
import com.bringspring.common.auth.model.LoginTicketModel;
import com.bringspring.common.auth.service.ThirdPartyAuthService;
import com.bringspring.common.auth.util.TicketUtil;
import com.bringspring.common.auth.util.UserProvider;
import com.bringspring.common.base.ActionResult;
import com.bringspring.common.base.UserInfo;
import com.bringspring.common.constant.MsgCode;
import com.bringspring.common.database.model.TenantVO;
import com.bringspring.common.database.util.TenantDataSourceUtil;
import com.bringspring.common.exception.LoginException;
import com.bringspring.common.model.login.BaseSystemInfo;
import com.bringspring.common.model.login.LoginForm;
import com.bringspring.common.model.login.LoginVO;
import com.bringspring.common.util.JsonUtil;
import com.bringspring.common.util.StringUtils;
import com.bringspring.oauth.model.SocialUnbindModel;
import com.bringspring.oauth.service.LoginService;
import com.bringspring.oauth.util.LoginHolder;
import com.bringspring.system.permission.entity.UserEntity;
import com.bringspring.system.permission.service.UserService;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import java.util.Date;
import java.util.Map;
import java.util.Objects;

import static com.bringspring.common.constant.CacheConsts.LOGIN_CACHE;
import static com.bringspring.common.util.Constants.ADMIN_KEY;


/**
 * 荣科演示账号验证码认证
 *
 * @author RKKJ开发平台组
 * @user N
 * @copyright 荣科科技股份有限公司
 * @date 2025/12/03 22:13
 */
@Slf4j
@Component(RkkjWxworkTokenGranter.GRANT_TYPE)
public class RkkjWxworkTokenGranter extends AbstractTokenGranter {

    public static final String GRANT_TYPE = "thirdauth";
    public static final Integer ORDER = 8;
    private static final String URL_LOGIN = "";


    public RkkjWxworkTokenGranter() {
        super(URL_LOGIN);
    }

    public RkkjWxworkTokenGranter(String authenticationUrl) {
        super(authenticationUrl);
    }

    @Autowired
    private UserService userApi;
    @Autowired
    protected LoginService loginService;

    @Autowired
    private UserDetailsServiceBuilder userDetailsServiceBuilder;

    @Autowired
    private ThirdPartyAuthService thirdPartyAuthService;


    @Override
    public ActionResult<LoginVO> granter(Map<String, String> loginParameters) throws LoginException {
        LoginForm loginForm = JsonUtil.getJsonToBean(loginParameters, LoginForm.class);
        UserInfo userInfo = UserProvider.getUser();
        //切换租户
        switchTenant(userInfo);
        //获取系统配置
        BaseSystemInfo baseSystemInfo = getSysconfig(userInfo);
        //预检信息
        preAuthenticate(loginForm, userInfo, baseSystemInfo);
        //登录账号
        super.loginAccount(userInfo, baseSystemInfo);
        //返回登录信息
        LoginVO loginResult = getLoginVo(userInfo);
        return ActionResult.success(loginResult);
    }

    @Override
    public int getOrder() {
        return ORDER;
    }

    /**
     * 可重写实现邮箱、短信、TOTP验证
     *
     * @param loginForm
     * @param sysConfigInfo
     * @throws LoginException
     */
    protected void preAuthenticate(LoginForm loginForm, UserInfo userInfo, BaseSystemInfo sysConfigInfo) throws LoginException {
        // 验证第三方授权是否成功
        boolean verifyResult;
        try {
            verifyResult = thirdPartyAuthService.thirdPartyVerify(loginForm.getThirdType(), loginForm.getProductId(), loginForm.getCode());
        } catch (Exception e) {
            throw new LoginException("第三方授权验证失败", e.getMessage());
        }
        if (!verifyResult) {
            throw new LoginException("第三方授权验证未通过");
        }

        //验证密码
        UserEntity userEntity = null;
        try {
            userEntity = userDetailsServiceBuilder.getUserDetailService(AuthConsts.USERDETAIL_ACCOUNT).loadUserEntity(userInfo);
        } catch (LoginException e) {
            throw new RuntimeException(e);
        }
        // 设置登录密码
        loginForm.setPassword(userEntity.getPassword());

        userInfo.setUserId(userEntity.getId());
        userInfo.setUserName(userEntity.getRealName());
        UserProvider.setLocalLoginUser(userInfo);
        // 判断是否开启验证码
        if (Objects.nonNull(sysConfigInfo) && "1".equals(String.valueOf(sysConfigInfo.getEnableVerificationCode()))) {
            // 验证验证码
            String code = loginForm.getCode();
            String timestamp = (String) redisUtil.getString(loginForm.getTimestamp());
            if (StringUtils.isEmpty(code)) {
                throw new LoginException(MsgCode.LOG103.get());
            }
            if (StringUtils.isEmpty(timestamp)) {
                throw new LoginException("时间戳不能为空");
            }
            String codeCache = String.valueOf(cacheUtil.query(LOGIN_CACHE, timestamp));
            if (StringUtils.isEmpty(codeCache)) {
                throw new LoginException(MsgCode.LOG107.get());
            }
            if (!code.toLowerCase().equals(codeCache.toLowerCase())) {
                throw new LoginException(MsgCode.LOG106.get());
            }
        }
        try {
            authenticate(loginForm, userEntity, sysConfigInfo);
        } catch (Exception e) {
            authenticateFailure(userEntity, sysConfigInfo);
            throw e;
        }
        LoginHolder.setUserEntity(userEntity);
    }

    protected void authenticate(LoginForm loginForm, UserEntity userEntity, BaseSystemInfo systemInfo) throws LoginException {
        authenticateLock(userEntity, systemInfo);
        /**
         * 验证用户是否可以使用
         */
        loginService.isExistUser(userEntity, systemInfo);
    }

    protected void authenticateLock(UserEntity userEntity, BaseSystemInfo systemInfo) throws LoginException {
        // 判断当前账号是否被锁定
        Integer lockMark = userEntity.getEnabledMark();
        if (Objects.nonNull(lockMark) && lockMark == 2) {
            // 获取解锁时间
            Date unlockTime = userEntity.getUnlockTime();
            // 账号锁定
            if (systemInfo.getLockType() == 1 || Objects.isNull(unlockTime)) {
                throw new LoginException(MsgCode.LOG012.get());
            }
            // 延迟登陆锁定
            long millis = System.currentTimeMillis();
            if (unlockTime.getTime() > millis) {
                // 转成分钟
                int time = (int) ((unlockTime.getTime() - millis) / (1000 * 60));
                throw new LoginException(MsgCode.LOG108.get(time + 1));
            } else if (unlockTime.getTime() < millis && userEntity.getLogErrorCount() >= systemInfo.getPasswordErrorsNumber()) {
                // 已经接触错误时间锁定的话就重置错误次数
                userEntity.setLogErrorCount(0);
                userEntity.setEnabledMark(1);
                userApi.updateById(userEntity);
            }
        }
    }


    protected void authenticateFailure(UserEntity entity, BaseSystemInfo sysConfigInfo) {
        if (entity != null) {
            // 超级管理员特权，不会锁定
            if (!ADMIN_KEY.equals(entity.getAccount())) {
                // 判断是否需要锁定账号，哪种锁定方式
                // 大于2则判断有效
                Integer errorsNumber = sysConfigInfo.getPasswordErrorsNumber();
                // 判断是否开启
                if (errorsNumber != null && errorsNumber > 2) {
                    // 加入错误次数
                    Integer errorCount = entity.getLogErrorCount() != null ? entity.getLogErrorCount() + 1 : 1;
                    entity.setLogErrorCount(errorCount);
                    Integer lockType = sysConfigInfo.getLockType();
                    if (errorCount >= errorsNumber) {
                        entity.setEnabledMark(2);
                        // 如果是延时锁定
                        if (Objects.nonNull(lockType) && lockType == 2) {
                            Integer lockTime = sysConfigInfo.getLockTime();
                            Date date = new Date((System.currentTimeMillis() + (lockTime * 60 * 1000)));
                            entity.setUnlockTime(date);
                        }
                    }
                    if (lockType == 1) {
                        entity.setUnlockTime(null);
                    }
                    userApi.updateById(entity);
                }
            }
        }
    }

    @Override
    protected void preLogin(UserInfo userInfo, BaseSystemInfo baseSystemInfo) throws LoginException {

    }

    @Override
    protected void loginSuccess(UserInfo userInfo, BaseSystemInfo baseSystemInfo) {
        super.loginSuccess(userInfo, baseSystemInfo);
        //登录成功绑定第三方
        if (SaHolder.getRequest().hasParam(AuthConsts.PARAMS_JNPF_TICKET)) {
            String ticket = SaHolder.getRequest().getParam(AuthConsts.PARAMS_JNPF_TICKET);
            LoginTicketModel ticketModel = TicketUtil.parseTicket(ticket);
            if (ticketModel != null) {
                SocialUnbindModel jsonToBean = JsonUtil.getJsonToBean(ticketModel.getValue(), SocialUnbindModel.class);
                if (jsonToBean != null) {
                    // 单点登录
//                    socialsUserApi.loginAutoBinding(jsonToBean.getSocialType(), jsonToBean.getSocialUnionid(), jsonToBean.getSocialName(),
//                            userInfo.getUserId(), userInfo.getTenantId());
                }
            }
        }
        if (SaHolder.getRequest().hasParam(AuthConsts.Client_Id)) {
            String Client_Id = SaHolder.getRequest().getParam(AuthConsts.Client_Id);
            if (StringUtils.isNotBlank(Client_Id) && !"null".equals(Client_Id)) {
//                UserDeviceEntity userDeviceEntity = userDeviceService.getInfoByClientId(Client_Id);
//                if (userDeviceEntity != null) {
//                    userDeviceEntity.setUserId(userInfo.getUserId());
//                    userDeviceEntity.setLastModifyTime(DateUtil.getNowDate());
//                    userDeviceEntity.setLastModifyUserId(userInfo.getUserId());
//                    userDeviceService.update(userDeviceEntity.getId(), userDeviceEntity);
//                } else {
//                    userDeviceEntity = new UserDeviceEntity();
//                    userDeviceEntity.setId(RandomUtil.uuId());
//                    userDeviceEntity.setUserId(userInfo.getUserId());
//                    userDeviceEntity.setClientId(Client_Id);
//                    userDeviceEntity.setCreatorTime(DateUtil.getNowDate());
//                    userDeviceEntity.setCreatorUserId(userInfo.getUserId());
//                    userDeviceService.create(userDeviceEntity);
//                }
            }
        }
    }

    protected LoginVO getLoginVo(UserInfo userInfo) {
        LoginVO loginVO = new LoginVO();
        loginVO.setTheme(userInfo.getTheme());
        loginVO.setToken(userInfo.getToken());
        if (configValueUtil.isMultiTenancy()) {
            //删除卫翎信息
            TenantVO tenantVO = TenantDataSourceUtil.getCacheTenantInfo(userInfo.getTenantId());
            if (tenantVO != null && tenantVO.getWl_qrcode() != null) {
                loginVO.setWl_qrcode(tenantVO.getWl_qrcode());
                tenantVO.setWl_qrcode(null);
                TenantDataSourceUtil.setTenantInfo(tenantVO);
            }
        }
        return loginVO;
    }

    @Override
    public ActionResult logout() {
        UserInfo userInfo = UserProvider.getUser();
        if (userInfo.getUserId() != null) {
            if ("1".equals(String.valueOf(loginSatokenService.getBaseSystemConfig(userInfo.getTenantId()).getSingleLogin()))) {
                UserProvider.logoutByUserId(userInfo.getUserId(), DeviceType.valueOf(userInfo.getLoginDevice()));
            } else {
                UserProvider.logoutByToken(userInfo.getToken());
            }
        }
        return ActionResult.success(MsgCode.OA014.get());
    }

    @Override
    protected String getGrantType() {
        return GRANT_TYPE;
    }

    @Override
    protected String getUserDetailKey() {
        return AuthConsts.USERDETAIL_ACCOUNT;
    }
}

==> jsbos-oauth-2025.12.03-dev-sources.jar: com/bringspring/oauth/granter/RkkjWxworkTokenGranter.java <==
package com.bringspring.oauth.granter;

import cn.dev33.satoken.context.SaHolder;
import com.bringspring.common.auth.consts.AuthConsts;
import com.bringspring.common.auth.consts.DeviceType;
import com.bringspring.common.auth.granter.AbstractTokenGranter;
import com.bringspring.common.auth.granter.UserDetailsServiceBuilder;
import com.bringspring.common.auth.model.LoginTicketModel;
import com.bringspring.common.auth.service.ThirdPartyAuthService;
import com.bringspring.common.auth.util.TicketUtil;
import com.bringspring.common.auth.util.UserProvider;
import com.bringspring.common.base.ActionResult;
import com.bringspring.common.base.UserInfo;
import com.bringspring.common.constant.MsgCode;
import com.bringspring.common.database.model.TenantVO;
import com.bringspring.common.database.util.TenantDataSourceUtil;
import com.bringspring.common.exception.LoginException;
import com.bringspring.common.model.login.BaseSystemInfo;
import com.bringspring.common.model.login.LoginForm;
import com.bringspring.common.model.login.LoginVO;
import com.bringspring.common.util.JsonUtil;
import com.bringspring.common.util.StringUtils;
import com.bringspring.oauth.model.SocialUnbindModel;
import com.bringspring.oauth.service.LoginService;
import com.bringspring.oauth.util.LoginHolder;
import com.bringspring.system.permission.entity.UserEntity;
import com.bringspring.system.permission.service.UserService;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import java.util.Date;
import java.util.Map;
import java.util.Objects;

import static com.bringspring.common.constant.CacheConsts.LOGIN_CACHE;
import static com.bringspring.common.util.Constants.ADMIN_KEY;


/**
 * 荣科演示账号验证码认证
 *
 * @author RKKJ开发平台组
 * @user N
 * @copyright 荣科科技股份有限公司
 * @date 2025/12/03 22:13
 */
@Slf4j
@Component(RkkjWxworkTokenGranter.GRANT_TYPE)
public class RkkjWxworkTokenGranter extends AbstractTokenGranter {

    public static final String GRANT_TYPE = "thirdauth";
    public static final Integer ORDER = 8;
    private static final String URL_LOGIN = "";


    public RkkjWxworkTokenGranter() {
        super(URL_LOGIN);
    }

    public RkkjWxworkTokenGranter(String authenticationUrl) {
        super(authenticationUrl);
    }

    @Autowired
    private UserService userApi;
    @Autowired
    protected LoginService loginService;

    @Autowired
    private UserDetailsServiceBuilder userDetailsServiceBuilder;

    @Autowired
    private ThirdPartyAuthService thirdPartyAuthService;


    @Override
    public ActionResult<LoginVO> granter(Map<String, String> loginParameters) throws LoginException {
        LoginForm loginForm = JsonUtil.getJsonToBean(loginParameters, LoginForm.class);
        UserInfo userInfo = UserProvider.getUser();
        //切换租户
        switchTenant(userInfo);
        //获取系统配置
        BaseSystemInfo baseSystemInfo = getSysconfig(userInfo);
        //预检信息
        preAuthenticate(loginForm, userInfo, baseSystemInfo);
        //登录账号
        super.loginAccount(userInfo, baseSystemInfo);
        //返回登录信息
        LoginVO loginResult = getLoginVo(userInfo);
        return ActionResult.success(loginResult);
    }

    @Override
    public int getOrder() {
        return ORDER;
    }

    /**
     * 可重写实现邮箱、短信、TOTP验证
     *
     * @param loginForm
     * @param sysConfigInfo
     * @throws LoginException
     */
    protected void preAuthenticate(LoginForm loginForm, UserInfo userInfo, BaseSystemInfo sysConfigInfo) throws LoginException {
        // 验证第三方授权是否成功
        boolean verifyResult;
        try {
            verifyResult = thirdPartyAuthService.thirdPartyVerify(loginForm.getThirdType(), loginForm.getProductId(), loginForm.getCode());
        } catch (Exception e) {
            throw new LoginException("第三方授权验证失败", e.getMessage());
        }
        if (!verifyResult) {
            throw new LoginException("第三方授权验证未通过");
        }

        //验证密码
        UserEntity userEntity = null;
        try {
            userEntity = userDetailsServiceBuilder.getUserDetailService(AuthConsts.USERDETAIL_ACCOUNT).loadUserEntity(userInfo);
        } catch (LoginException e) {
            throw new RuntimeException(e);
        }
        // 设置登录密码
        loginForm.setPassword(userEntity.getPassword());

        userInfo.setUserId(userEntity.getId());
        userInfo.setUserName(userEntity.getRealName());
        UserProvider.setLocalLoginUser(userInfo);
        // 判断是否开启验证码
        if (Objects.nonNull(sysConfigInfo) && "1".equals(String.valueOf(sysConfigInfo.getEnableVerificationCode()))) {
            // 验证验证码
            String code = loginForm.getCode();
            String timestamp = (String) redisUtil.getString(loginForm.getTimestamp());
            if (StringUtils.isEmpty(code)) {
                throw new LoginException(MsgCode.LOG103.get());
            }
            if (StringUtils.isEmpty(timestamp)) {
                throw new LoginException("时间戳不能为空");
            }
            String codeCache = String.valueOf(cacheUtil.query(LOGIN_CACHE, timestamp));
            if (StringUtils.isEmpty(codeCache)) {
                throw new LoginException(MsgCode.LOG107.get());
            }
            if (!code.toLowerCase().equals(codeCache.toLowerCase())) {
                throw new LoginException(MsgCode.LOG106.get());
            }
        }
        try {
            authenticate(loginForm, userEntity, sysConfigInfo);
        } catch (Exception e) {
            authenticateFailure(userEntity, sysConfigInfo);
            throw e;
        }
        LoginHolder.setUserEntity(userEntity);
    }

    protected void authenticate(LoginForm loginForm, UserEntity userEntity, BaseSystemInfo systemInfo) throws LoginException {
        authenticateLock(userEntity, systemInfo);
        /**
         * 验证用户是否可以使用
         */
        loginService.isExistUser(userEntity, systemInfo);
    }

    protected void authenticateLock(UserEntity userEntity, BaseSystemInfo systemInfo) throws LoginException {
        // 判断当前账号是否被锁定
        Integer lockMark = userEntity.getEnabledMark();
        if (Objects.nonNull(lockMark) && lockMark == 2) {
            // 获取解锁时间
            Date unlockTime = userEntity.getUnlockTime();
            // 账号锁定
            if (systemInfo.getLockType() == 1 || Objects.isNull(unlockTime)) {
                throw new LoginException(MsgCode.LOG012.get());
            }
            // 延迟登陆锁定
            long millis = System.currentTimeMillis();
            if (unlockTime.getTime() > millis) {
                // 转成分钟
                int time = (int) ((unlockTime.getTime() - millis) / (1000 * 60));
                throw new LoginException(MsgCode.LOG108.get(time + 1));
            } else if (unlockTime.getTime() < millis && userEntity.getLogErrorCount() >= systemInfo.getPasswordErrorsNumber()) {
                // 已经接触错误时间锁定的话就重置错误次数
                userEntity.setLogErrorCount(0);
                userEntity.setEnabledMark(1);
                userApi.updateById(userEntity);
            }
        }
    }


    protected void authenticateFailure(UserEntity entity, BaseSystemInfo sysConfigInfo) {
        if (entity != null) {
            // 超级管理员特权，不会锁定
            if (!ADMIN_KEY.equals(entity.getAccount())) {
                // 判断是否需要锁定账号，哪种锁定方式
                // 大于2则判断有效
                Integer errorsNumber = sysConfigInfo.getPasswordErrorsNumber();
                // 判断是否开启
                if (errorsNumber != null && errorsNumber > 2) {
                    // 加入错误次数
                    Integer errorCount = entity.getLogErrorCount() != null ? entity.getLogErrorCount() + 1 : 1;
                    entity.setLogErrorCount(errorCount);
                    Integer lockType = sysConfigInfo.getLockType();
                    if (errorCount >= errorsNumber) {
                        entity.setEnabledMark(2);
                        // 如果是延时锁定
                        if (Objects.nonNull(lockType) && lockType == 2) {
                            Integer lockTime = sysConfigInfo.getLockTime();
                            Date date = new Date((System.currentTimeMillis() + (lockTime * 60 * 1000)));
                            entity.setUnlockTime(date);
                        }
                    }
                    if (lockType == 1) {
                        entity.setUnlockTime(null);
                    }
                    userApi.updateById(entity);
                }
            }
        }
    }

    @Override
    protected void preLogin(UserInfo userInfo, BaseSystemInfo baseSystemInfo) throws LoginException {

    }

    @Override
    protected void loginSuccess(UserInfo userInfo, BaseSystemInfo baseSystemInfo) {
        super.loginSuccess(userInfo, baseSystemInfo);
        //登录成功绑定第三方
        if (SaHolder.getRequest().hasParam(AuthConsts.PARAMS_JSBOS_TICKET)) {
            String ticket = SaHolder.getRequest().getParam(AuthConsts.PARAMS_JSBOS_TICKET);
            LoginTicketModel ticketModel = TicketUtil.parseTicket(ticket);
            if (ticketModel != null) {
                SocialUnbindModel jsonToBean = JsonUtil.getJsonToBean(ticketModel.getValue(), SocialUnbindModel.class);
                if (jsonToBean != null) {
                    // 单点登录
//                    socialsUserApi.loginAutoBinding(jsonToBean.getSocialType(), jsonToBean.getSocialUnionid(), jsonToBean.getSocialName(),
//                            userInfo.getUserId(), userInfo.getTenantId());
                }
            }
        }
        if (SaHolder.getRequest().hasParam(AuthConsts.Client_Id)) {
            String Client_Id = SaHolder.getRequest().getParam(AuthConsts.Client_Id);
            if (StringUtils.isNotBlank(Client_Id) && !"null".equals(Client_Id)) {
//                UserDeviceEntity userDeviceEntity = userDeviceService.getInfoByClientId(Client_Id);
//                if (userDeviceEntity != null) {
//                    userDeviceEntity.setUserId(userInfo.getUserId());
//                    userDeviceEntity.setLastModifyTime(DateUtil.getNowDate());
//                    userDeviceEntity.setLastModifyUserId(userInfo.getUserId());
//                    userDeviceService.update(userDeviceEntity.getId(), userDeviceEntity);
//                } else {
//                    userDeviceEntity = new UserDeviceEntity();
//                    userDeviceEntity.setId(RandomUtil.uuId());
//                    userDeviceEntity.setUserId(userInfo.getUserId());
//                    userDeviceEntity.setClientId(Client_Id);
//                    userDeviceEntity.setCreatorTime(DateUtil.getNowDate());
//                    userDeviceEntity.setCreatorUserId(userInfo.getUserId());
//                    userDeviceService.create(userDeviceEntity);
//                }
            }
        }
    }

    protected LoginVO getLoginVo(UserInfo userInfo) {
        LoginVO loginVO = new LoginVO();
        loginVO.setTheme(userInfo.getTheme());
        loginVO.setToken(userInfo.getToken());
        if (configValueUtil.isMultiTenancy()) {
            //删除卫翎信息
            TenantVO tenantVO = TenantDataSourceUtil.getCacheTenantInfo(userInfo.getTenantId());
            if (tenantVO != null && tenantVO.getWl_qrcode() != null) {
                loginVO.setWl_qrcode(tenantVO.getWl_qrcode());
                tenantVO.setWl_qrcode(null);
                TenantDataSourceUtil.setTenantInfo(tenantVO);
            }
        }
        return loginVO;
    }

    @Override
    public ActionResult logout() {
        UserInfo userInfo = UserProvider.getUser();
        if (userInfo.getUserId() != null) {
            if ("1".equals(String.valueOf(loginSatokenService.getBaseSystemConfig(userInfo.getTenantId()).getSingleLogin()))) {
                UserProvider.logoutByUserId(userInfo.getUserId(), DeviceType.valueOf(userInfo.getLoginDevice()));
            } else {
                UserProvider.logoutByToken(userInfo.getToken());
            }
        }
        return ActionResult.success(MsgCode.OA014.get());
    }

    @Override
    protected String getGrantType() {
        return GRANT_TYPE;
    }

    @Override
    protected String getUserDetailKey() {
        return AuthConsts.USERDETAIL_ACCOUNT;
    }
}
